==> pagseguroplugin-0.0.5.tar.gz: android/src/main/kotlin/com/pagseguro/pagseguroplugin/PagseguroPlugin.kt <==
package com.pagseguro.pagseguroplugin

import android.app.Activity
import android.content.Context
import android.os.Build
import android.util.Log
import br.com.uol.pagseguro.plugpagservice.wrapper.PlugPag
import br.com.uol.pagseguro.plugpagservice.wrapper.PlugPagActivationData
import br.com.uol.pagseguro.plugpagservice.wrapper.PlugPagAppIdentification
import br.com.uol.pagseguro.plugpagservice.wrapper.data.request.PlugPagBeepData
import com.pagseguro.pagseguroplugin.domain.PaymentRequestData
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.FlutterPlugin.FlutterPluginBinding
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.PluginRegistry.Registrar
import java.lang.Exception

class PagseguroPlugin : FlutterPlugin, MethodCallHandler, ActivityAware {

    private lateinit var plugPag: PlugPag
    private lateinit var appName: String
    private lateinit var appVersion: String
    private lateinit var activationCode: String
    private lateinit var context: Context
    private lateinit var activity: Activity

    override fun onAttachedToActivity(binding: ActivityPluginBinding) {
        activity = binding.activity
        context = activity.application.applicationContext
    }


    override fun onDetachedFromActivity() {
        // TDO("not implemented") //To change body of created functions use File | Settings | File Templates.
    }

    override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
        // TDO("not implemented") //To change body of created functions use File | Settings | File Templates.
    }

    override fun onDetachedFromActivityForConfigChanges() {
        //TDO("not implemented") //To change body of created functions use File | Settings | File Templates.
    }

    override fun onAttachedToEngine(binding: FlutterPluginBinding) {}
    override fun onDetachedFromEngine(binding: FlutterPluginBinding) {}
    override fun onMethodCall(call: MethodCall, result: MethodChannel.Result) {
        if(call.method.equals("getPlatformVersion")){
            return result.success("ok");
        }else if(call.method.equals("getModel")){
            return result.success(Build.MODEL);
        }else if(call.method.equals("initialize")){
            return initialize(call, result)
        }
        result.notImplemented()
    }

    fun initialize(call: MethodCall, result: MethodChannel.Result) {
        Log.d("PAG_PLUGIN", "initialize")
        appName = call.argument<String>("appName")!!
        appVersion = call.argument<String>("appVersion")!!
        activationCode = call.argument<String>("activationCode")!!
        try {
            plugPag = PlugPag(context, PlugPagAppIdentification(appName, appVersion))
            plugPag.initializeAndActivatePinpad(PlugPagActivationData(activationCode))
            plugPag.beep(PlugPagBeepData(1, 10))
            result.success(true)
        }catch (err: Exception){
            result.error("1234", "initializarion error", "")
        }
    }

    fun createPayment(call: MethodCall?, result: MethodChannel.Result?) {
        val paymentRequestData = PaymentRequestData()
    }

    fun getInstallments(call: MethodCall?, result: MethodChannel.Result?) {}

    companion object {
        private var channel: MethodChannel? = null
        fun registerWith(registrar: Registrar) {
            channel = MethodChannel(registrar.messenger(), "pagseguroplugin")
            channel!!.setMethodCallHandler(PagseguroPlugin())
        }
    }
}

==> pagseguroplugin-0.0.6.tar.gz: android/src/main/kotlin/com/pagseguro/pagseguroplugin/PagseguroPlugin.kt <==
package com.pagseguro.pagseguroplugin

import android.app.Activity
import android.content.Context
import android.os.Build
import android.util.Log
import br.com.uol.pagseguro.plugpagservice.wrapper.PlugPag
import br.com.uol.pagseguro.plugpagservice.wrapper.PlugPag.Companion.INSTALLMENT_TYPE_PARC_COMPRADOR
import br.com.uol.pagseguro.plugpagservice.wrapper.PlugPag.Companion.RET_OK
import br.com.uol.pagseguro.plugpagservice.wrapper.PlugPag.Companion.TYPE_CREDITO
import br.com.uol.pagseguro.plugpagservice.wrapper.PlugPag.Companion.TYPE_DEBITO
import br.com.uol.pagseguro.plugpagservice.wrapper.PlugPag.Companion.TYPE_VOUCHER
import br.com.uol.pagseguro.plugpagservice.wrapper.PlugPagActivationData
import br.com.uol.pagseguro.plugpagservice.wrapper.PlugPagAppIdentification
import br.com.uol.pagseguro.plugpagservice.wrapper.PlugPagPaymentData
import br.com.uol.pagseguro.plugpagservice.wrapper.data.request.PlugPagBeepData
import com.pagseguro.pagseguroplugin.domain.PaymentRequestData
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.FlutterPlugin.FlutterPluginBinding
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.PluginRegistry.Registrar
import java.lang.Exception
import java.math.BigDecimal
import java.math.BigDecimal.ZERO

class PagseguroPlugin : FlutterPlugin, MethodCallHandler, ActivityAware {

    private lateinit var plugPag: PlugPag
    private lateinit var appName: String
    private lateinit var appVersion: String
    private lateinit var activationCode: String
    private lateinit var context: Context
    private lateinit var activity: Activity

    override fun onAttachedToActivity(binding: ActivityPluginBinding) {
        activity = binding.activity
        context = activity.application.applicationContext
    }


    override fun onDetachedFromActivity() {
        // TDO("not implemented") //To change body of created functions use File | Settings | File Templates.
    }

    override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
        // TDO("not implemented") //To change body of created functions use File | Settings | File Templates.
    }

    override fun onDetachedFromActivityForConfigChanges() {
        //TDO("not implemented") //To change body of created functions use File | Settings | File Templates.
    }

    override fun onAttachedToEngine(binding: FlutterPluginBinding) {}
    override fun onDetachedFromEngine(binding: FlutterPluginBinding) {}
    override fun onMethodCall(call: MethodCall, result: MethodChannel.Result) {
        if(call.method == "getPlatformVersion"){
            return result.success("ok");
        }else if(call.method == "getModel"){
            return result.success(Build.MODEL);
        }else if(call.method == "initialize"){
            return initialize(call, result)
        }else if(call.method == "startPayment"){
            return startPayment(call, result)
        }

        result.notImplemented()
    }

    fun initialize(call: MethodCall, result: MethodChannel.Result) {
        Log.d("PAG_PLUGIN", "initialize")
        appName = call.argument<String>("appName")!!
        appVersion = call.argument<String>("appVersion")!!
        activationCode = call.argument<String>("activationCode")!!
        try {
            plugPag = PlugPag(context, PlugPagAppIdentification(appName, appVersion))
            plugPag.initializeAndActivatePinpad(PlugPagActivationData(activationCode))
            plugPag.beep(PlugPagBeepData(1, 10))
            result.success(true)
        }catch (err: Exception){
            result.error("1234", "initializarion error", "")
        }
    }

    fun startPayment(call: MethodCall, result: MethodChannel.Result){

        var amount = call.argument<BigDecimal>("amount") !!

        var installments = call.argument<Long>("installments") !!

        var type = call.argument<String>("type") !!

        var paymentId = call.argument<String>("paymentId") !!

        var resultPAG = plugPag.doPayment(PlugPagPaymentData(
                if(type == "C") TYPE_CREDITO else (if (type == "D") TYPE_DEBITO else TYPE_VOUCHER)
                , amount.multiply(BigDecimal(100)).intValueExact(), INSTALLMENT_TYPE_PARC_COMPRADOR, installments.toInt(), paymentId, true))

        result.success(resultPAG.result == RET_OK)

    }

    fun createPayment(call: MethodCall?, result: MethodChannel.Result?) {
        val paymentRequestData = PaymentRequestData()
    }

    fun getInstallments(call: MethodCall?, result: MethodChannel.Result?) {}

    companion object {
        private var channel: MethodChannel? = null
        fun registerWith(registrar: Registrar) {
            channel = MethodChannel(registrar.messenger(), "pagseguroplugin")
            channel!!.setMethodCallHandler(PagseguroPlugin())
        }
    }
}
